using System.Windows.Forms;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace XnaInForm
{
    public partial class XnaView : UserControl
    {
        #region Members & Properties

        public delegate void PaintFunction(XnaView ctrl);
        private PaintFunction paintMe;

        private Vector4 clearColor;
        public Vector4 ClearColor
        {
            get { return clearColor; }
        }

        private RenderTarget2D renderTarget;
        public RenderTarget2D RenderTarget
        {
            get { return renderTarget; }
        }

        private DepthStencilBuffer depthStencil;
        public DepthStencilBuffer DepthStencil
        {
            get { return depthStencil; }
        }

        private Texture2D texture;
        public Texture2D Texture
        {
            get { return texture; }
            set { texture = value; }
        }
	
        public Rectangle ClientArea
        {
            get { return new Rectangle(0, 0, Width, Height); }
        }

        #endregion

        #region Code

        public XnaView()
        {
            InitializeComponent();
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            if(paintMe != null)
                paintMe(this);
        }
        
        protected override void OnPaintBackground(PaintEventArgs e)
        {
        }
        
        public void Initialize(GraphicsDevice gfxDevice, PaintFunction paintFct, Vector4 clearColor)
        {
            this.paintMe = paintFct;
            this.clearColor = clearColor;

            renderTarget = new RenderTarget2D(gfxDevice, Width, Height, 1, SurfaceFormat.Color);
            depthStencil = new DepthStencilBuffer(gfxDevice, Width, Height, DepthFormat.Depth24);
        }

        #endregion
    }
}
